@@ -23,6 +23,8 @@ class DnsmasqConfig(JobServerPlugin):
             'mprov_url': self.js.mprovURL,
             'enableDHCP': True,
         }
+        os.makedirs(self.dnsmasqConfDir, exist_ok=True)
+        os.makedirs(self.tftproot, exist_ok=True)
         with open(self.dnsmasqConfDir + '/ipxe.conf', 'w') as conf:
             conf.write(jenv.get_template('dnsmasq/ipxe.conf.j2').render(data))
         jobquery = "&jobserver=" + str(self.js.id) + "&module=[\"dns-update\",\"dns-delete\",\"pxe-update\",\"dhcp-update\",\"pxe-delete\",\"dhcp-delete\"]"
@@ -39,9 +41,9 @@ class DnsmasqConfig(JobServerPlugin):
         else:
             print("Error: Unable to copy " + self.undionlyImg + " to " + self.tftproot)
         # restart dnsmasq
-        os.system('systemctl stop dnsmasq')
-        os.system('systemctl start dnsmasq')
+        os.system('systemctl restart dnsmasq')
         # copy in our ipxe.menu file.
+        
         with open(self.tftproot + '/menu.ipxe', 'w') as conf:
             conf.write(jenv.get_template('dnsmasq/menu.ipxe.j2').render(data))
         self.js.update_job_status(self.jobModule, 4, jobquery=jobquery + "&status=2")
\ No newline at end of file
